// src/index.ts
import { is as is6 } from "drizzle-orm";
import { MySqlDatabase as MySqlDatabase2 } from "drizzle-orm/mysql-core";
import { PgDatabase as PgDatabase2 } from "drizzle-orm/pg-core";
import { BaseSQLiteDatabase as BaseSQLiteDatabase2 } from "drizzle-orm/sqlite-core";
import { GraphQLObjectType as GraphQLObjectType5, GraphQLSchema } from "graphql";

// src/util/builders/mysql.ts
import { createTableRelationsHelpers, is as is3, Relations } from "drizzle-orm";
import { MySqlTable } from "drizzle-orm/mysql-core";
import {
  GraphQLBoolean as GraphQLBoolean3,
  GraphQLError as GraphQLError3,
  GraphQLInt as GraphQLInt3,
  GraphQLList as GraphQLList3,
  GraphQLNonNull as GraphQLNonNull3,
  GraphQLObjectType as GraphQLObjectType2,
  Kind as Kind2
} from "graphql";

// src/util/builders/common.ts
import {
  and,
  asc,
  desc,
  eq,
  getTableColumns as getTableColumns2,
  gt,
  gte,
  ilike,
  inArray,
  is as is2,
  isNotNull,
  isNull,
  like,
  lt,
  lte,
  ne,
  notIlike,
  notInArray,
  notLike,
  One,
  or
} from "drizzle-orm";
import {
  GraphQLBoolean as GraphQLBoolean2,
  GraphQLEnumType,
  GraphQLError as GraphQLError2,
  GraphQLInputObjectType,
  GraphQLInt as GraphQLInt2,
  GraphQLList as GraphQLList2,
  GraphQLNonNull as GraphQLNonNull2,
  GraphQLObjectType,
  GraphQLString as GraphQLString2,
  Kind
} from "graphql";
import { parseResolveInfo } from "graphql-parse-resolve-info";

// src/util/case-ops/index.ts
var camelize = (input) => input.toLocaleLowerCase();
var pascalize = (input) => input.length ? `${input[0].toLocaleUpperCase()}${input.length > 1 ? input.slice(1, input.length) : ""}` : input;

// src/util/data-mappers/index.ts
import { getTableColumns } from "drizzle-orm";
import { GraphQLError } from "graphql";
var remapToGraphQLCore = (key, value, relations) => {
  if (value instanceof Date)
    return value.toISOString();
  if (value instanceof Buffer)
    return Array.from(value);
  if (typeof value === "bigint")
    return value.toString();
  if (Array.isArray(value)) {
    if (relations?.[key])
      return remapToGraphQLArrayOutput(value);
    return value.map((arrVal) => remapToGraphQLCore(key, arrVal));
  }
  if (typeof value === "object") {
    if (relations?.[key])
      return remapToGraphQLSingleOutput(value);
    return JSON.stringify(value);
  }
  return value;
};
var remapToGraphQLSingleOutput = (queryOutput, relations) => {
  for (const [key, value] of Object.entries(queryOutput)) {
    if (value === void 0 || value === null) {
      delete queryOutput[key];
    } else {
      queryOutput[key] = remapToGraphQLCore(key, value, relations);
    }
  }
  return queryOutput;
};
var remapToGraphQLArrayOutput = (queryOutput, relations) => {
  for (const entry of queryOutput)
    remapToGraphQLSingleOutput(entry, relations);
  return queryOutput;
};
var remapFromGraphQLCore = (value, column, columnName) => {
  switch (column.dataType) {
    case "date": {
      const formatted = new Date(value);
      if (Number.isNaN(formatted.getTime()))
        throw new GraphQLError(`Field '${columnName}' is not a valid date!`);
      return formatted;
    }
    case "buffer": {
      if (!Array.isArray(value)) {
        throw new GraphQLError(`Field '${columnName}' is not an array!`);
      }
      return Buffer.from(value);
    }
    case "json": {
      try {
        return JSON.parse(value);
      } catch (e) {
        throw new GraphQLError(
          `Invalid JSON in field '${columnName}':
${e instanceof Error ? e.message : "Unknown error"}`
        );
      }
    }
    case "array": {
      if (!Array.isArray(value)) {
        throw new GraphQLError(`Field '${columnName}' is not an array!`);
      }
      return value;
    }
    case "bigint": {
      try {
        return BigInt(value);
      } catch (error) {
        throw new GraphQLError(`Field '${columnName}' is not a BigInt!`);
      }
    }
    default: {
      return value;
    }
  }
};
var remapFromGraphQLSingleInput = (queryInput, table) => {
  for (const [key, value] of Object.entries(queryInput)) {
    if (value === void 0) {
      delete queryInput[key];
    } else {
      const column = getTableColumns(table)[key];
      if (!column)
        throw new GraphQLError(`Unknown column: ${key}`);
      if (value === null && column.notNull) {
        delete queryInput[key];
        continue;
      }
      queryInput[key] = remapFromGraphQLCore(value, column, key);
    }
  }
  return queryInput;
};
var remapFromGraphQLArrayInput = (queryInput, table) => {
  for (const entry of queryInput)
    remapFromGraphQLSingleInput(entry, table);
  return queryInput;
};

// src/util/type-converter/index.ts
import { is } from "drizzle-orm";
import { MySqlInt, MySqlSerial } from "drizzle-orm/mysql-core";
import { PgInteger, PgSerial } from "drizzle-orm/pg-core";
import { SQLiteInteger } from "drizzle-orm/sqlite-core";
import {
  GraphQLBoolean,
  GraphQLFloat,
  GraphQLInt,
  GraphQLList,
  GraphQLNonNull,
  GraphQLString
} from "graphql";
var columnToGraphQLCore = (column) => {
  switch (column.dataType) {
    case "boolean":
      return { type: GraphQLBoolean, description: "Boolean" };
    case "json":
      return { type: GraphQLString, description: "JSON" };
    case "date":
      return { type: GraphQLString, description: "Date" };
    case "string":
      return { type: GraphQLString, description: "String" };
    case "bigint":
      return { type: GraphQLString, description: "BigInt" };
    case "number":
      return is(column, PgInteger) || is(column, PgSerial) || is(column, MySqlInt) || is(column, MySqlSerial) || is(column, SQLiteInteger) ? { type: GraphQLInt, description: "Integer" } : { type: GraphQLFloat, description: "Float" };
    case "buffer":
      return { type: new GraphQLList(new GraphQLNonNull(GraphQLInt)), description: "Buffer" };
    case "array": {
      const innerType = columnToGraphQLCore(column.baseColumn);
      return {
        type: new GraphQLList(new GraphQLNonNull(innerType.type)),
        description: `Array<${innerType.description}>`
      };
    }
    case "custom":
    default:
      throw new Error(`Type ${column.dataType} is not implemented!`);
  }
};
var drizzleColumnToGraphQLType = (column, forceNullable = false, defaultIsNullable = false) => {
  const typeDesc = columnToGraphQLCore(column);
  const noDesc = ["string", "boolean", "number"];
  if (noDesc.find((e) => e === column.dataType))
    delete typeDesc.description;
  if (forceNullable)
    return typeDesc;
  if (column.notNull && !(defaultIsNullable && (column.hasDefault || column.defaultFn))) {
    return {
      type: new GraphQLNonNull(typeDesc.type),
      description: typeDesc.description
    };
  }
  return typeDesc;
};

// src/util/builders/common.ts
var extractSelectedColumnsFromNode = (info, table) => {
  if (!info.selectionSet)
    return {};
  const tableColumns = getTableColumns2(table);
  const selectedColumns = [];
  for (const columnSelection of info.selectionSet.selections) {
    if (columnSelection.kind !== Kind.FIELD || !tableColumns[columnSelection.name.value])
      continue;
    selectedColumns.push([columnSelection.name.value, true]);
  }
  return Object.fromEntries(selectedColumns);
};
var extractSelectedColumnsSQLFormat = (info, queryName, table) => {
  const tableSelection = info.operation.selectionSet.selections.find(
    (e) => e.kind === Kind.FIELD && e.name.value === queryName
  );
  const selectedColumns = [];
  if (!tableSelection || !tableSelection.selectionSet)
    throw new GraphQLError2("Received empty column selection!");
  for (const columnSelection of tableSelection.selectionSet.selections) {
    if (columnSelection.kind !== Kind.FIELD)
      continue;
    selectedColumns.push([columnSelection.name.value, table[columnSelection.name.value]]);
  }
  return Object.fromEntries(selectedColumns);
};
var innerOrder = new GraphQLInputObjectType({
  name: "InnerOrder",
  fields: {
    direction: {
      type: new GraphQLNonNull2(
        new GraphQLEnumType({
          name: "OrderDirection",
          description: "Order by direction",
          values: {
            asc: {
              value: "asc",
              description: "Ascending order"
            },
            desc: {
              value: "desc",
              description: "Descending order"
            }
          }
        })
      )
    },
    priority: { type: new GraphQLNonNull2(GraphQLInt2), description: "Priority of current field" }
  }
});
var generateColumnFilterValues = (column, tableName, columnName) => {
  const columnGraphQLType = drizzleColumnToGraphQLType(column, true);
  const columnArr = new GraphQLList2(new GraphQLNonNull2(columnGraphQLType.type));
  const baseFields = {
    eq: { type: columnGraphQLType.type, description: columnGraphQLType.description },
    ne: { type: columnGraphQLType.type, description: columnGraphQLType.description },
    lt: { type: columnGraphQLType.type, description: columnGraphQLType.description },
    lte: { type: columnGraphQLType.type, description: columnGraphQLType.description },
    gt: { type: columnGraphQLType.type, description: columnGraphQLType.description },
    gte: { type: columnGraphQLType.type, description: columnGraphQLType.description },
    like: { type: GraphQLString2 },
    notLike: { type: GraphQLString2 },
    ilike: { type: GraphQLString2 },
    notIlike: { type: GraphQLString2 },
    inArray: { type: columnArr, description: `Array<${columnGraphQLType.description}>` },
    notInArray: { type: columnArr, description: `Array<${columnGraphQLType.description}>` },
    isNull: { type: GraphQLBoolean2 },
    isNotNull: { type: GraphQLBoolean2 }
  };
  const type = new GraphQLInputObjectType({
    name: `${pascalize(tableName)}${pascalize(columnName)}Filters`,
    fields: {
      ...baseFields,
      OR: {
        type: new GraphQLList2(
          new GraphQLNonNull2(
            new GraphQLInputObjectType({
              name: `${pascalize(tableName)}${pascalize(columnName)}filtersOr`,
              fields: {
                ...baseFields
              }
            })
          )
        )
      }
    }
  });
  return type;
};
var filterMap = /* @__PURE__ */ new WeakMap();
var generateTableFilterValuesCached = (table, tableName) => {
  if (filterMap.has(table))
    return filterMap.get(table);
  const columns = getTableColumns2(table);
  const columnEntries = Object.entries(columns);
  const remapped = Object.fromEntries(
    columnEntries.map(([columnName, columnDescription]) => [
      columnName,
      {
        type: generateColumnFilterValues(columnDescription, tableName, columnName)
      }
    ])
  );
  filterMap.set(table, remapped);
  return remapped;
};
var fieldMap = /* @__PURE__ */ new WeakMap();
var generateTableSelectTypeFieldsCached = (table) => {
  if (fieldMap.has(table))
    return fieldMap.get(table);
  const columns = getTableColumns2(table);
  const columnEntries = Object.entries(columns);
  const remapped = Object.fromEntries(
    columnEntries.map(([columnName, columnDescription]) => [
      columnName,
      drizzleColumnToGraphQLType(columnDescription)
    ])
  );
  fieldMap.set(table, remapped);
  return remapped;
};
var generateTableTypes = (tableName, table, withReturning, relations) => {
  const relationEntries = relations ? Object.entries(relations) : [];
  const relationFields = Object.fromEntries(
    relationEntries.map(([relName, relValue]) => {
      const relTableFields = Object.fromEntries(
        Object.entries(getTableColumns2(relValue.referencedTable)).map(([columnName, columnDescription]) => [
          columnName,
          drizzleColumnToGraphQLType(columnDescription)
        ])
      );
      const type = new GraphQLObjectType({
        name: `${pascalize(tableName)}${pascalize(relName)}Relation`,
        fields: relTableFields
      });
      const relationFilterColumns = generateTableFilterValuesCached(relValue.referencedTable, relName);
      const where = new GraphQLInputObjectType({
        name: `${pascalize(tableName)}${pascalize(relName)}RelationFilters`,
        fields: {
          ...relationFilterColumns,
          OR: {
            type: new GraphQLList2(
              new GraphQLNonNull2(
                new GraphQLInputObjectType({
                  name: `${pascalize(tableName)}${pascalize(relName)}RelationFiltersOr`,
                  fields: relationFilterColumns
                })
              )
            )
          }
        }
      });
      if (is2(relValue, One)) {
        return [
          relName,
          {
            type,
            args: {
              where: { type: where }
            }
          }
        ];
      }
      const orderBy = new GraphQLInputObjectType({
        name: `${pascalize(tableName)}${pascalize(relName)}RelationOrder`,
        fields: Object.fromEntries(
          Object.entries(relValue.referencedTable).map(([columnName, columnDescription]) => [
            columnName,
            { type: innerOrder }
          ])
        )
      });
      return [
        relName,
        {
          type: new GraphQLNonNull2(new GraphQLList2(new GraphQLNonNull2(type))),
          args: {
            where: { type: where },
            orderBy: { type: orderBy },
            offset: { type: GraphQLInt2 },
            limit: { type: GraphQLInt2 }
          }
        }
      ];
    })
  );
  const tableFields = generateTableSelectTypeFieldsCached(table);
  const columns = getTableColumns2(table);
  const columnEntries = Object.entries(columns);
  const insertFields = Object.fromEntries(
    columnEntries.map(([columnName, columnDescription]) => [
      columnName,
      drizzleColumnToGraphQLType(columnDescription, false, true)
    ])
  );
  const updateFields = Object.fromEntries(
    columnEntries.map(([columnName, columnDescription]) => [
      columnName,
      drizzleColumnToGraphQLType(columnDescription, true)
    ])
  );
  const insertInput = new GraphQLInputObjectType({
    name: `${pascalize(tableName)}InsertInput`,
    fields: insertFields
  });
  const selectSingleOutput = new GraphQLObjectType({
    name: `${pascalize(tableName)}SelectItem`,
    fields: { ...tableFields, ...relationFields }
  });
  const selectArrOutput = new GraphQLNonNull2(new GraphQLList2(new GraphQLNonNull2(selectSingleOutput)));
  const singleTableItemOutput = withReturning ? new GraphQLObjectType({
    name: `${pascalize(tableName)}Item`,
    fields: tableFields
  }) : void 0;
  const arrTableItemOutput = withReturning ? new GraphQLNonNull2(new GraphQLList2(new GraphQLNonNull2(singleTableItemOutput))) : void 0;
  const updateInput = new GraphQLInputObjectType({
    name: `${pascalize(tableName)}UpdateInput`,
    fields: updateFields
  });
  const tableOrder = new GraphQLInputObjectType({
    name: `${pascalize(tableName)}OrderBy`,
    fields: Object.fromEntries(
      columnEntries.map(([columnName, columnDescription]) => [columnName, { type: innerOrder }])
    )
  });
  const filterColumns = generateTableFilterValuesCached(table, tableName);
  const tableFilters = new GraphQLInputObjectType({
    name: `${pascalize(tableName)}Filters`,
    fields: {
      ...filterColumns,
      OR: {
        type: new GraphQLList2(
          new GraphQLNonNull2(
            new GraphQLInputObjectType({
              name: `${pascalize(tableName)}FiltersOr`,
              fields: filterColumns
            })
          )
        )
      }
    }
  });
  const inputs = {
    insertInput,
    updateInput,
    tableOrder,
    tableFilters
  };
  const outputs = withReturning ? {
    selectSingleOutput,
    selectArrOutput,
    singleTableItemOutput,
    arrTableItemOutput
  } : {
    selectSingleOutput,
    selectArrOutput
  };
  return {
    inputs,
    outputs
  };
};
var extractOrderBy = (table, orderArgs) => {
  const res = [];
  for (const [column, config] of Object.entries(orderArgs).sort(
    (a, b) => (b[1]?.priority ?? 0) - (a[1]?.priority ?? 0)
  )) {
    if (!config)
      continue;
    const { direction } = config;
    res.push(direction === "asc" ? asc(getTableColumns2(table)[column]) : desc(getTableColumns2(table)[column]));
  }
  return res;
};
var extractFiltersColumn = (column, columnName, operators) => {
  if (!operators.OR?.length)
    delete operators.OR;
  const entries = Object.entries(operators);
  if (operators.OR) {
    if (entries.length > 1) {
      throw new GraphQLError2(`WHERE ${columnName}: Cannot specify both fields and 'OR' in column operators!`);
    }
    const variants2 = [];
    for (const variant of operators.OR) {
      const extracted = extractFiltersColumn(column, columnName, variant);
      if (extracted)
        variants2.push(extracted);
    }
    return variants2.length ? variants2.length > 1 ? or(...variants2) : variants2[0] : void 0;
  }
  const variants = [];
  for (const [operatorName, operatorValue] of entries) {
    if (operatorValue === null || operatorValue === false)
      continue;
    let operator;
    switch (operatorName) {
      case "eq":
        operator = operator ?? eq;
      case "ne":
        operator = operator ?? ne;
      case "gt":
        operator = operator ?? gt;
      case "gte":
        operator = operator ?? gte;
      case "lt":
        operator = operator ?? lt;
      case "lte":
        operator = operator ?? lte;
        const singleValue = remapFromGraphQLCore(operatorValue, column, columnName);
        variants.push(operator(column, singleValue));
        break;
      case "like":
        operator = operator ?? like;
      case "notLike":
        operator = operator ?? notLike;
      case "ilike":
        operator = operator ?? ilike;
      case "notIlike":
        operator = operator ?? notIlike;
        variants.push(operator(column, operatorValue));
        break;
      case "inArray":
        operator = operator ?? inArray;
      case "notInArray":
        operator = operator ?? notInArray;
        if (!operatorValue.length) {
          throw new GraphQLError2(
            `WHERE ${columnName}: Unable to use operator ${operatorName} with an empty array!`
          );
        }
        const arrayValue = operatorValue.map((val) => remapFromGraphQLCore(val, column, columnName));
        variants.push(operator(column, arrayValue));
        break;
      case "isNull":
        operator = operator ?? isNull;
      case "isNotNull":
        operator = operator ?? isNotNull;
        variants.push(operator(column));
    }
  }
  return variants.length ? variants.length > 1 ? and(...variants) : variants[0] : void 0;
};
var extractFilters = (table, tableName, filters) => {
  if (!filters.OR?.length)
    delete filters.OR;
  const entries = Object.entries(filters);
  if (!entries.length)
    return;
  if (filters.OR) {
    if (entries.length > 1) {
      throw new GraphQLError2(`WHERE ${tableName}: Cannot specify both fields and 'OR' in table filters!`);
    }
    const variants2 = [];
    for (const variant of filters.OR) {
      const extracted = extractFilters(table, tableName, variant);
      if (extracted)
        variants2.push(extracted);
    }
    return variants2.length ? variants2.length > 1 ? or(...variants2) : variants2[0] : void 0;
  }
  const variants = [];
  for (const [columnName, operators] of entries) {
    if (operators === null)
      continue;
    const column = getTableColumns2(table)[columnName];
    variants.push(extractFiltersColumn(column, columnName, operators));
  }
  return variants.length ? variants.length > 1 ? and(...variants) : variants[0] : void 0;
};
var extractRelationsParams = (relations, tableSelection, typeName, info) => {
  const fields = {};
  const parsedInfo = parseResolveInfo(info, {
    deep: true
  });
  const baseField = parsedInfo ? Object.entries(parsedInfo.fieldsByTypeName).find(([key, value]) => key === typeName)?.[1] ?? {} : {};
  for (const [relName, relValue] of Object.entries(relations)) {
    if (!tableSelection.selectionSet)
      continue;
    const node = tableSelection.selectionSet.selections.find(
      (e) => e.kind === Kind.FIELD && e.name.value === relName
    );
    if (!node)
      continue;
    const refTable = relValue.referencedTable;
    const columns = extractSelectedColumnsFromNode(node, refTable);
    const relationArgs = Object.values(baseField).find((e) => e.name === relName)?.args;
    if (!relationArgs) {
      fields[relName] = {
        columns
      };
      continue;
    }
    const orderBy = relationArgs.orderBy ? extractOrderBy(refTable, relationArgs.orderBy) : void 0;
    const where = relationArgs.where ? extractFilters(refTable, relName, relationArgs?.where) : void 0;
    const offset = relationArgs.offset ?? void 0;
    const limit = relationArgs.limit ?? void 0;
    fields[relName] = {
      columns,
      orderBy,
      where,
      offset,
      limit
    };
  }
  return Object.keys(fields).length ? fields : void 0;
};

// src/util/builders/mysql.ts
var generateSelectArray = (db, tableName, table, relations, orderArgs, filterArgs) => {
  const queryName = `${camelize(tableName)}`;
  const queryBase = db.query[tableName];
  if (!queryBase) {
    throw new Error(
      `Table ${tableName} not found in drizzle instance. Did you forget to pass schema to drizzle constructor?`
    );
  }
  const queryArgs = {
    offset: {
      type: GraphQLInt3
    },
    limit: {
      type: GraphQLInt3
    },
    orderBy: {
      type: orderArgs
    },
    where: {
      type: filterArgs
    }
  };
  return {
    name: queryName,
    resolver: async (source, args, context, info) => {
      try {
        const { offset, limit, orderBy, where } = args;
        const tableSelection = info.operation.selectionSet.selections.find(
          (e) => e.kind === Kind2.FIELD && e.name.value === info.fieldName
        );
        const query = queryBase.findMany({
          columns: extractSelectedColumnsFromNode(tableSelection, table),
          offset,
          limit,
          orderBy: orderBy ? extractOrderBy(table, orderBy) : void 0,
          where: where ? extractFilters(table, tableName, where) : void 0,
          with: relations ? extractRelationsParams(relations, tableSelection, `${pascalize(tableName)}SelectItem`, info) : void 0
        });
        const result = await query;
        return remapToGraphQLArrayOutput(result, relations);
      } catch (e) {
        if (typeof e === "object" && typeof e.message === "string") {
          throw new GraphQLError3(e.message);
        }
        throw e;
      }
    },
    args: queryArgs
  };
};
var generateSelectSingle = (db, tableName, table, relations, orderArgs, filterArgs) => {
  const queryName = `${camelize(tableName)}Single`;
  const queryBase = db.query[tableName];
  if (!queryBase) {
    throw new Error(
      `Table ${tableName} not found in drizzle instance. Did you forget to pass schema to drizzle constructor?`
    );
  }
  const queryArgs = {
    offset: {
      type: GraphQLInt3
    },
    orderBy: {
      type: orderArgs
    },
    where: {
      type: filterArgs
    }
  };
  return {
    name: queryName,
    resolver: async (source, args, context, info) => {
      try {
        const { offset, orderBy, where } = args;
        const tableSelection = info.operation.selectionSet.selections.find(
          (e) => e.kind === Kind2.FIELD && e.name.value === info.fieldName
        );
        const columns = extractSelectedColumnsFromNode(tableSelection, table);
        const withFields = relations ? extractRelationsParams(relations, tableSelection, `${pascalize(tableName)}SelectItem`, info) : void 0;
        const query = queryBase.findFirst({
          columns,
          offset,
          orderBy: orderBy ? extractOrderBy(table, orderBy) : void 0,
          where: where ? extractFilters(table, tableName, where) : void 0,
          with: withFields
        });
        const result = await query;
        if (!result)
          return void 0;
        return remapToGraphQLSingleOutput(result, relations);
      } catch (e) {
        if (typeof e === "object" && typeof e.message === "string") {
          throw new GraphQLError3(e.message);
        }
        throw e;
      }
    },
    args: queryArgs
  };
};
var generateInsertArray = (db, tableName, table, baseType) => {
  const queryName = `insertInto${pascalize(tableName)}`;
  const queryArgs = {
    values: {
      type: new GraphQLNonNull3(new GraphQLList3(new GraphQLNonNull3(baseType)))
    }
  };
  return {
    name: queryName,
    resolver: async (source, args, context, info) => {
      try {
        const input = remapFromGraphQLArrayInput(args.values, table);
        if (!input.length)
          throw new GraphQLError3("No values were provided!");
        await db.insert(table).values(input);
        return { isSuccess: true };
      } catch (e) {
        if (typeof e === "object" && typeof e.message === "string") {
          throw new GraphQLError3(e.message);
        }
        throw e;
      }
    },
    args: queryArgs
  };
};
var generateInsertSingle = (db, tableName, table, baseType) => {
  const queryName = `insertInto${pascalize(tableName)}Single`;
  const queryArgs = {
    values: {
      type: new GraphQLNonNull3(baseType)
    }
  };
  return {
    name: queryName,
    resolver: async (source, args, context, info) => {
      try {
        const input = remapFromGraphQLSingleInput(args.values, table);
        await db.insert(table).values(input);
        return { isSuccess: true };
      } catch (e) {
        if (typeof e === "object" && typeof e.message === "string") {
          throw new GraphQLError3(e.message);
        }
        throw e;
      }
    },
    args: queryArgs
  };
};
var generateUpdate = (db, tableName, table, setArgs, filterArgs) => {
  const queryName = `update${pascalize(tableName)}`;
  const queryArgs = {
    set: {
      type: new GraphQLNonNull3(setArgs)
    },
    where: {
      type: filterArgs
    }
  };
  return {
    name: queryName,
    resolver: async (source, args, context, info) => {
      try {
        const { where, set } = args;
        const input = remapFromGraphQLSingleInput(set, table);
        if (!Object.keys(input).length)
          throw new GraphQLError3("Unable to update with no values specified!");
        let query = db.update(table).set(input);
        if (where) {
          const filters = extractFilters(table, tableName, where);
          query = query.where(filters);
        }
        await query;
        return { isSuccess: true };
      } catch (e) {
        if (typeof e === "object" && typeof e.message === "string") {
          throw new GraphQLError3(e.message);
        }
        throw e;
      }
    },
    args: queryArgs
  };
};
var generateDelete = (db, tableName, table, filterArgs) => {
  const queryName = `deleteFrom${tableName}`;
  const queryArgs = {
    where: {
      type: filterArgs
    }
  };
  return {
    name: queryName,
    resolver: async (source, args, context, info) => {
      try {
        const { where } = args;
        let query = db.delete(table);
        if (where) {
          const filters = extractFilters(table, tableName, where);
          query = query.where(filters);
        }
        await query;
        return { isSuccess: true };
      } catch (e) {
        if (typeof e === "object" && typeof e.message === "string") {
          throw new GraphQLError3(e.message);
        }
        throw e;
      }
    },
    args: queryArgs
  };
};
var generateSchemaData = (db, schema) => {
  const rawSchema = schema;
  const schemaEntries = Object.entries(rawSchema);
  const tables = Object.fromEntries(schemaEntries.filter(([key, value]) => is3(value, MySqlTable)));
  if (!tables || !Object.keys(tables).length) {
    throw new Error(
      `Unable to extract tables from drizzle instance.
Did you forget to pass tables to graphql schema constructor?`
    );
  }
  const relations = Object.fromEntries(
    schemaEntries.filter(([key, value]) => is3(value, Relations)).map(([key, value]) => [
      Object.entries(tables).find(
        ([tableName, tableValue]) => tableValue === value.table
      )[0],
      value
    ]).map(([tableName, relValue]) => [
      tableName,
      relValue.config(createTableRelationsHelpers(tables[tableName]))
    ])
  );
  const queries = {};
  const mutations = {};
  const gqlSchemaTypes = Object.fromEntries(
    Object.entries(tables).map(([tableName, table]) => [
      tableName,
      generateTableTypes(tableName, table, false, relations[tableName])
    ])
  );
  const mutationReturnType = new GraphQLObjectType2({
    name: `MutationReturn`,
    fields: {
      isSuccess: {
        type: new GraphQLNonNull3(GraphQLBoolean3)
      }
    }
  });
  const inputs = {};
  const outputs = {
    MutationReturn: mutationReturnType
  };
  for (const [tableName, tableTypes] of Object.entries(gqlSchemaTypes)) {
    const { insertInput, updateInput, tableFilters, tableOrder } = tableTypes.inputs;
    const { selectSingleOutput, selectArrOutput } = tableTypes.outputs;
    const selectArrGenerated = generateSelectArray(
      db,
      tableName,
      schema[tableName],
      relations[tableName],
      tableOrder,
      tableFilters
    );
    const selectSingleGenerated = generateSelectSingle(
      db,
      tableName,
      schema[tableName],
      relations[tableName],
      tableOrder,
      tableFilters
    );
    const insertArrGenerated = generateInsertArray(db, tableName, schema[tableName], insertInput);
    const insertSingleGenerated = generateInsertSingle(db, tableName, schema[tableName], insertInput);
    const updateGenerated = generateUpdate(
      db,
      tableName,
      schema[tableName],
      updateInput,
      tableFilters
    );
    const deleteGenerated = generateDelete(db, tableName, schema[tableName], tableFilters);
    queries[selectArrGenerated.name] = {
      type: selectArrOutput,
      args: selectArrGenerated.args,
      resolve: selectArrGenerated.resolver
    };
    queries[selectSingleGenerated.name] = {
      type: selectSingleOutput,
      args: selectSingleGenerated.args,
      resolve: selectSingleGenerated.resolver
    };
    mutations[insertArrGenerated.name] = {
      type: mutationReturnType,
      args: insertArrGenerated.args,
      resolve: insertArrGenerated.resolver
    };
    mutations[insertSingleGenerated.name] = {
      type: mutationReturnType,
      args: insertSingleGenerated.args,
      resolve: insertSingleGenerated.resolver
    };
    mutations[updateGenerated.name] = {
      type: mutationReturnType,
      args: updateGenerated.args,
      resolve: updateGenerated.resolver
    };
    mutations[deleteGenerated.name] = {
      type: mutationReturnType,
      args: deleteGenerated.args,
      resolve: deleteGenerated.resolver
    };
    [insertInput, updateInput, tableFilters, tableOrder].forEach((e) => inputs[e.name] = e);
    outputs[selectSingleOutput.name] = selectSingleOutput;
  }
  return { queries, mutations, inputs, types: outputs };
};

// src/util/builders/pg.ts
import { createTableRelationsHelpers as createTableRelationsHelpers2, is as is4, Relations as Relations2 } from "drizzle-orm";
import { PgTable } from "drizzle-orm/pg-core";
import {
  GraphQLError as GraphQLError4,
  GraphQLInt as GraphQLInt4,
  GraphQLList as GraphQLList4,
  GraphQLNonNull as GraphQLNonNull4,
  Kind as Kind3
} from "graphql";
var generateSelectArray2 = (db, tableName, table, relations, orderArgs, filterArgs) => {
  const queryName = `${camelize(tableName)}`;
  const queryBase = db.query[tableName];
  if (!queryBase) {
    throw new Error(
      `Table ${tableName} not found in drizzle instance. Did you forget to pass schema to drizzle constructor?`
    );
  }
  const queryArgs = {
    offset: {
      type: GraphQLInt4
    },
    limit: {
      type: GraphQLInt4
    },
    orderBy: {
      type: orderArgs
    },
    where: {
      type: filterArgs
    }
  };
  return {
    name: queryName,
    resolver: async (source, args, context, info) => {
      try {
        const { offset, limit, orderBy, where } = args;
        const tableSelection = info.operation.selectionSet.selections.find(
          (e) => e.kind === Kind3.FIELD && e.name.value === info.fieldName
        );
        const query = queryBase.findMany({
          columns: extractSelectedColumnsFromNode(tableSelection, table),
          offset,
          limit,
          orderBy: orderBy ? extractOrderBy(table, orderBy) : void 0,
          where: where ? extractFilters(table, tableName, where) : void 0,
          with: relations ? extractRelationsParams(relations, tableSelection, `${pascalize(tableName)}SelectItem`, info) : void 0
        });
        const result = await query;
        return remapToGraphQLArrayOutput(result, relations);
      } catch (e) {
        if (typeof e === "object" && typeof e.message === "string") {
          throw new GraphQLError4(e.message);
        }
        throw e;
      }
    },
    args: queryArgs
  };
};
var generateSelectSingle2 = (db, tableName, table, relations, orderArgs, filterArgs) => {
  const queryName = `${camelize(tableName)}Single`;
  const queryBase = db.query[tableName];
  if (!queryBase) {
    throw new Error(
      `Table ${tableName} not found in drizzle instance. Did you forget to pass schema to drizzle constructor?`
    );
  }
  const queryArgs = {
    offset: {
      type: GraphQLInt4
    },
    orderBy: {
      type: orderArgs
    },
    where: {
      type: filterArgs
    }
  };
  return {
    name: queryName,
    resolver: async (source, args, context, info) => {
      try {
        const { offset, orderBy, where } = args;
        const tableSelection = info.operation.selectionSet.selections.find(
          (e) => e.kind === Kind3.FIELD && e.name.value === info.fieldName
        );
        const query = queryBase.findFirst({
          columns: extractSelectedColumnsFromNode(tableSelection, table),
          offset,
          orderBy: orderBy ? extractOrderBy(table, orderBy) : void 0,
          where: where ? extractFilters(table, tableName, where) : void 0,
          with: relations ? extractRelationsParams(relations, tableSelection, `${pascalize(tableName)}SelectItem`, info) : void 0
        });
        const result = await query;
        if (!result)
          return void 0;
        return remapToGraphQLSingleOutput(result, relations);
      } catch (e) {
        if (typeof e === "object" && typeof e.message === "string") {
          throw new GraphQLError4(e.message);
        }
        throw e;
      }
    },
    args: queryArgs
  };
};
var generateInsertArray2 = (db, tableName, table, baseType) => {
  const queryName = `insertInto${pascalize(tableName)}`;
  const queryArgs = {
    values: {
      type: new GraphQLNonNull4(new GraphQLList4(new GraphQLNonNull4(baseType)))
    }
  };
  return {
    name: queryName,
    resolver: async (source, args, context, info) => {
      try {
        const input = remapFromGraphQLArrayInput(args.values, table);
        if (!input.length)
          throw new GraphQLError4("No values were provided!");
        const columns = extractSelectedColumnsSQLFormat(info, info.fieldName, table);
        const result = await db.insert(table).values(input).returning(columns).onConflictDoNothing();
        return remapToGraphQLArrayOutput(result);
      } catch (e) {
        if (typeof e === "object" && typeof e.message === "string") {
          throw new GraphQLError4(e.message);
        }
        throw e;
      }
    },
    args: queryArgs
  };
};
var generateInsertSingle2 = (db, tableName, table, baseType) => {
  const queryName = `insertInto${pascalize(tableName)}Single`;
  const queryArgs = {
    values: {
      type: new GraphQLNonNull4(baseType)
    }
  };
  return {
    name: queryName,
    resolver: async (source, args, context, info) => {
      try {
        const input = remapFromGraphQLSingleInput(args.values, table);
        const columns = extractSelectedColumnsSQLFormat(info, info.fieldName, table);
        const result = await db.insert(table).values(input).returning(columns).onConflictDoNothing();
        if (!result[0])
          return void 0;
        return remapToGraphQLSingleOutput(result[0]);
      } catch (e) {
        if (typeof e === "object" && typeof e.message === "string") {
          throw new GraphQLError4(e.message);
        }
        throw e;
      }
    },
    args: queryArgs
  };
};
var generateUpdate2 = (db, tableName, table, setArgs, filterArgs) => {
  const queryName = `update${pascalize(tableName)}`;
  const queryArgs = {
    set: {
      type: new GraphQLNonNull4(setArgs)
    },
    where: {
      type: filterArgs
    }
  };
  return {
    name: queryName,
    resolver: async (source, args, context, info) => {
      try {
        const { where, set } = args;
        const columns = extractSelectedColumnsSQLFormat(info, info.fieldName, table);
        const input = remapFromGraphQLSingleInput(set, table);
        if (!Object.keys(input).length)
          throw new GraphQLError4("Unable to update with no values specified!");
        let query = db.update(table).set(input);
        if (where) {
          const filters = extractFilters(table, tableName, where);
          query = query.where(filters);
        }
        query = query.returning(columns);
        const result = await query;
        return remapToGraphQLArrayOutput(result);
      } catch (e) {
        if (typeof e === "object" && typeof e.message === "string") {
          throw new GraphQLError4(e.message);
        }
        throw e;
      }
    },
    args: queryArgs
  };
};
var generateDelete2 = (db, tableName, table, filterArgs) => {
  const queryName = `deleteFrom${pascalize(tableName)}`;
  const queryArgs = {
    where: {
      type: filterArgs
    }
  };
  return {
    name: queryName,
    resolver: async (source, args, context, info) => {
      try {
        const { where } = args;
        const columns = extractSelectedColumnsSQLFormat(info, info.fieldName, table);
        let query = db.delete(table);
        if (where) {
          const filters = extractFilters(table, tableName, where);
          query = query.where(filters);
        }
        query = query.returning(columns);
        const result = await query;
        return remapToGraphQLArrayOutput(result);
      } catch (e) {
        if (typeof e === "object" && typeof e.message === "string") {
          throw new GraphQLError4(e.message);
        }
        throw e;
      }
    },
    args: queryArgs
  };
};
var generateSchemaData2 = (db, schema) => {
  const rawSchema = schema;
  const schemaEntries = Object.entries(rawSchema);
  const tables = Object.fromEntries(schemaEntries.filter(([key, value]) => is4(value, PgTable)));
  if (!tables || !Object.keys(tables).length) {
    throw new Error(
      `Unable to extract tables from drizzle instance.
Did you forget to pass tables to graphql schema constructor?`
    );
  }
  const relations = Object.fromEntries(
    schemaEntries.filter(([key, value]) => is4(value, Relations2)).map(([key, value]) => [
      Object.entries(tables).find(
        ([tableName, tableValue]) => tableValue === value.table
      )[0],
      value
    ]).map(([tableName, relValue]) => [
      tableName,
      relValue.config(createTableRelationsHelpers2(tables[tableName]))
    ])
  );
  const queries = {};
  const mutations = {};
  const gqlSchemaTypes = Object.fromEntries(
    Object.entries(tables).map(([tableName, table]) => [
      tableName,
      generateTableTypes(tableName, table, true, relations[tableName])
    ])
  );
  const inputs = {};
  const outputs = {};
  for (const [tableName, tableTypes] of Object.entries(gqlSchemaTypes)) {
    const { insertInput, updateInput, tableFilters, tableOrder } = tableTypes.inputs;
    const { selectSingleOutput, selectArrOutput, singleTableItemOutput, arrTableItemOutput } = tableTypes.outputs;
    const selectArrGenerated = generateSelectArray2(
      db,
      tableName,
      schema[tableName],
      relations[tableName],
      tableOrder,
      tableFilters
    );
    const selectSingleGenerated = generateSelectSingle2(
      db,
      tableName,
      schema[tableName],
      relations[tableName],
      tableOrder,
      tableFilters
    );
    const insertArrGenerated = generateInsertArray2(db, tableName, schema[tableName], insertInput);
    const insertSingleGenerated = generateInsertSingle2(db, tableName, schema[tableName], insertInput);
    const updateGenerated = generateUpdate2(db, tableName, schema[tableName], updateInput, tableFilters);
    const deleteGenerated = generateDelete2(db, tableName, schema[tableName], tableFilters);
    queries[selectArrGenerated.name] = {
      type: selectArrOutput,
      args: selectArrGenerated.args,
      resolve: selectArrGenerated.resolver
    };
    queries[selectSingleGenerated.name] = {
      type: selectSingleOutput,
      args: selectSingleGenerated.args,
      resolve: selectSingleGenerated.resolver
    };
    mutations[insertArrGenerated.name] = {
      type: arrTableItemOutput,
      args: insertArrGenerated.args,
      resolve: insertArrGenerated.resolver
    };
    mutations[insertSingleGenerated.name] = {
      type: singleTableItemOutput,
      args: insertSingleGenerated.args,
      resolve: insertSingleGenerated.resolver
    };
    mutations[updateGenerated.name] = {
      type: arrTableItemOutput,
      args: updateGenerated.args,
      resolve: updateGenerated.resolver
    };
    mutations[deleteGenerated.name] = {
      type: arrTableItemOutput,
      args: deleteGenerated.args,
      resolve: deleteGenerated.resolver
    };
    [insertInput, updateInput, tableFilters, tableOrder].forEach((e) => inputs[e.name] = e);
    outputs[selectSingleOutput.name] = selectSingleOutput;
    outputs[singleTableItemOutput.name] = singleTableItemOutput;
  }
  return { queries, mutations, inputs, types: outputs };
};

// src/util/builders/sqlite.ts
import { createTableRelationsHelpers as createTableRelationsHelpers3, is as is5, Relations as Relations3 } from "drizzle-orm";
import { SQLiteTable } from "drizzle-orm/sqlite-core";
import {
  GraphQLError as GraphQLError5,
  GraphQLInt as GraphQLInt5,
  GraphQLList as GraphQLList5,
  GraphQLNonNull as GraphQLNonNull5,
  Kind as Kind4
} from "graphql";
var generateSelectArray3 = (db, tableName, table, relations, orderArgs, filterArgs) => {
  const queryName = `${camelize(tableName)}`;
  const queryBase = db.query[tableName];
  if (!queryBase) {
    throw new Error(
      `Table ${tableName} not found in drizzle instance. Did you forget to pass schema to drizzle constructor?`
    );
  }
  const queryArgs = {
    offset: {
      type: GraphQLInt5
    },
    limit: {
      type: GraphQLInt5
    },
    orderBy: {
      type: orderArgs
    },
    where: {
      type: filterArgs
    }
  };
  return {
    name: queryName,
    resolver: async (source, args, context, info) => {
      try {
        const { offset, limit, orderBy, where } = args;
        const tableSelection = info.operation.selectionSet.selections.find(
          (e) => e.kind === Kind4.FIELD && e.name.value === info.fieldName
        );
        const query = queryBase.findMany({
          columns: extractSelectedColumnsFromNode(tableSelection, table),
          offset,
          limit,
          orderBy: orderBy ? extractOrderBy(table, orderBy) : void 0,
          where: where ? extractFilters(table, tableName, where) : void 0,
          with: relations ? extractRelationsParams(relations, tableSelection, `${pascalize(tableName)}SelectItem`, info) : void 0
        });
        const result = await query;
        return remapToGraphQLArrayOutput(result, relations);
      } catch (e) {
        if (typeof e === "object" && typeof e.message === "string") {
          throw new GraphQLError5(e.message);
        }
        throw e;
      }
    },
    args: queryArgs
  };
};
var generateSelectSingle3 = (db, tableName, table, relations, orderArgs, filterArgs) => {
  const queryName = `${camelize(tableName)}Single`;
  const queryBase = db.query[tableName];
  if (!queryBase) {
    throw new Error(
      `Table ${tableName} not found in drizzle instance. Did you forget to pass schema to drizzle constructor?`
    );
  }
  const queryArgs = {
    offset: {
      type: GraphQLInt5
    },
    orderBy: {
      type: orderArgs
    },
    where: {
      type: filterArgs
    }
  };
  return {
    name: queryName,
    resolver: async (source, args, context, info) => {
      try {
        const { offset, orderBy, where } = args;
        const tableSelection = info.operation.selectionSet.selections.find(
          (e) => e.kind === Kind4.FIELD && e.name.value === info.fieldName
        );
        const query = queryBase.findFirst({
          columns: extractSelectedColumnsFromNode(tableSelection, table),
          offset,
          orderBy: orderBy ? extractOrderBy(table, orderBy) : void 0,
          where: where ? extractFilters(table, tableName, where) : void 0,
          with: relations ? extractRelationsParams(relations, tableSelection, `${pascalize(tableName)}SelectItem`, info) : void 0
        });
        const result = await query;
        if (!result)
          return void 0;
        return remapToGraphQLSingleOutput(result, relations);
      } catch (e) {
        if (typeof e === "object" && typeof e.message === "string") {
          throw new GraphQLError5(e.message);
        }
        throw e;
      }
    },
    args: queryArgs
  };
};
var generateInsertArray3 = (db, tableName, table, baseType) => {
  const queryName = `insertInto${pascalize(tableName)}`;
  const queryArgs = {
    values: {
      type: new GraphQLNonNull5(new GraphQLList5(new GraphQLNonNull5(baseType)))
    }
  };
  return {
    name: queryName,
    resolver: async (source, args, context, info) => {
      try {
        const input = remapFromGraphQLArrayInput(args.values, table);
        if (!input.length)
          throw new GraphQLError5("No values were provided!");
        const columns = extractSelectedColumnsSQLFormat(info, info.fieldName, table);
        const result = await db.insert(table).values(input).returning(columns).onConflictDoNothing();
        return remapToGraphQLArrayOutput(result);
      } catch (e) {
        if (typeof e === "object" && typeof e.message === "string") {
          throw new GraphQLError5(e.message);
        }
        throw e;
      }
    },
    args: queryArgs
  };
};
var generateInsertSingle3 = (db, tableName, table, baseType) => {
  const queryName = `insertInto${pascalize(tableName)}Single`;
  const queryArgs = {
    values: {
      type: new GraphQLNonNull5(baseType)
    }
  };
  return {
    name: queryName,
    resolver: async (source, args, context, info) => {
      try {
        const input = remapFromGraphQLSingleInput(args.values, table);
        const columns = extractSelectedColumnsSQLFormat(info, info.fieldName, table);
        const result = await db.insert(table).values(input).returning(columns).onConflictDoNothing();
        if (!result[0])
          return void 0;
        return remapToGraphQLSingleOutput(result[0]);
      } catch (e) {
        if (typeof e === "object" && typeof e.message === "string") {
          throw new GraphQLError5(e.message);
        }
        throw e;
      }
    },
    args: queryArgs
  };
};
var generateUpdate3 = (db, tableName, table, setArgs, filterArgs) => {
  const queryName = `update${pascalize(tableName)}`;
  const queryArgs = {
    set: {
      type: new GraphQLNonNull5(setArgs)
    },
    where: {
      type: filterArgs
    }
  };
  return {
    name: queryName,
    resolver: async (source, args, context, info) => {
      try {
        const { where, set } = args;
        const columns = extractSelectedColumnsSQLFormat(info, info.fieldName, table);
        const input = remapFromGraphQLSingleInput(set, table);
        if (!Object.keys(input).length)
          throw new GraphQLError5("Unable to update with no values specified!");
        let query = db.update(table).set(input);
        if (where) {
          const filters = extractFilters(table, tableName, where);
          query = query.where(filters);
        }
        query = query.returning(columns);
        const result = await query;
        return remapToGraphQLArrayOutput(result);
      } catch (e) {
        if (typeof e === "object" && typeof e.message === "string") {
          throw new GraphQLError5(e.message);
        }
        throw e;
      }
    },
    args: queryArgs
  };
};
var generateDelete3 = (db, tableName, table, filterArgs) => {
  const queryName = `deleteFrom${pascalize(tableName)}`;
  const queryArgs = {
    where: {
      type: filterArgs
    }
  };
  return {
    name: queryName,
    resolver: async (source, args, context, info) => {
      try {
        const { where } = args;
        const columns = extractSelectedColumnsSQLFormat(info, info.fieldName, table);
        let query = db.delete(table);
        if (where) {
          const filters = extractFilters(table, tableName, where);
          query = query.where(filters);
        }
        query = query.returning(columns);
        const result = await query;
        return remapToGraphQLArrayOutput(result);
      } catch (e) {
        if (typeof e === "object" && typeof e.message === "string") {
          throw new GraphQLError5(e.message);
        }
        throw e;
      }
    },
    args: queryArgs
  };
};
var generateSchemaData3 = (db, schema) => {
  const rawSchema = schema;
  const schemaEntries = Object.entries(rawSchema);
  const tables = Object.fromEntries(schemaEntries.filter(([key, value]) => is5(value, SQLiteTable)));
  if (!tables || !Object.keys(tables).length) {
    throw new Error(
      `Unable to extract tables from drizzle instance.
Did you forget to pass tables to graphql schema constructor?`
    );
  }
  const relations = Object.fromEntries(
    schemaEntries.filter(([key, value]) => is5(value, Relations3)).map(([key, value]) => [
      Object.entries(tables).find(
        ([tableName, tableValue]) => tableValue === value.table
      )[0],
      value
    ]).map(([tableName, relValue]) => [
      tableName,
      relValue.config(createTableRelationsHelpers3(tables[tableName]))
    ])
  );
  const queries = {};
  const mutations = {};
  const gqlSchemaTypes = Object.fromEntries(
    Object.entries(tables).map(([tableName, table]) => [
      tableName,
      generateTableTypes(tableName, table, true, relations[tableName])
    ])
  );
  const inputs = {};
  const outputs = {};
  for (const [tableName, tableTypes] of Object.entries(gqlSchemaTypes)) {
    const { insertInput, updateInput, tableFilters, tableOrder } = tableTypes.inputs;
    const { selectSingleOutput, selectArrOutput, singleTableItemOutput, arrTableItemOutput } = tableTypes.outputs;
    const selectArrGenerated = generateSelectArray3(
      db,
      tableName,
      schema[tableName],
      relations[tableName],
      tableOrder,
      tableFilters
    );
    const selectSingleGenerated = generateSelectSingle3(
      db,
      tableName,
      schema[tableName],
      relations[tableName],
      tableOrder,
      tableFilters
    );
    const insertArrGenerated = generateInsertArray3(db, tableName, schema[tableName], insertInput);
    const insertSingleGenerated = generateInsertSingle3(db, tableName, schema[tableName], insertInput);
    const updateGenerated = generateUpdate3(
      db,
      tableName,
      schema[tableName],
      updateInput,
      tableFilters
    );
    const deleteGenerated = generateDelete3(db, tableName, schema[tableName], tableFilters);
    queries[selectArrGenerated.name] = {
      type: selectArrOutput,
      args: selectArrGenerated.args,
      resolve: selectArrGenerated.resolver
    };
    queries[selectSingleGenerated.name] = {
      type: selectSingleOutput,
      args: selectSingleGenerated.args,
      resolve: selectSingleGenerated.resolver
    };
    mutations[insertArrGenerated.name] = {
      type: arrTableItemOutput,
      args: insertArrGenerated.args,
      resolve: insertArrGenerated.resolver
    };
    mutations[insertSingleGenerated.name] = {
      type: singleTableItemOutput,
      args: insertSingleGenerated.args,
      resolve: insertSingleGenerated.resolver
    };
    mutations[updateGenerated.name] = {
      type: arrTableItemOutput,
      args: updateGenerated.args,
      resolve: updateGenerated.resolver
    };
    mutations[deleteGenerated.name] = {
      type: arrTableItemOutput,
      args: deleteGenerated.args,
      resolve: deleteGenerated.resolver
    };
    [insertInput, updateInput, tableFilters, tableOrder].forEach((e) => inputs[e.name] = e);
    outputs[selectSingleOutput.name] = selectSingleOutput;
    outputs[singleTableItemOutput.name] = singleTableItemOutput;
  }
  return { queries, mutations, inputs, types: outputs };
};

// src/index.ts
var buildSchema = (db) => {
  const schema = db._.fullSchema;
  let generatorOutput;
  if (is6(db, MySqlDatabase2)) {
    generatorOutput = generateSchemaData(db, schema);
  } else if (is6(db, PgDatabase2)) {
    generatorOutput = generateSchemaData2(db, schema);
  } else if (is6(db, BaseSQLiteDatabase2)) {
    generatorOutput = generateSchemaData3(db, schema);
  } else
    throw new Error("Unknown database instance type");
  const { queries, mutations, inputs, types } = generatorOutput;
  const query = new GraphQLObjectType5({
    name: "Query",
    fields: queries
  });
  const mutation = new GraphQLObjectType5({
    name: "Mutation",
    fields: mutations
  });
  const outputSchema = new GraphQLSchema({
    query,
    mutation,
    types: [...Object.values(inputs), ...Object.values(types)]
  });
  return { schema: outputSchema, entities: generatorOutput };
};
export {
  buildSchema
};
//# sourceMappingURL=index.js.map